@@ -5,8 +5,6 @@ version = ''.join(sys.version.split('.')[:2])
 home = os.getcwd()
 path, mode, *_ = sys.argv[1:]
 folder, filename, ext = linux.path_break(path)
-# ~/.config/Code/User/keybindings.json
-# /home/quang/.local/lib/python3.10/site-packages/tayto/execute.py
 
 
 if mode == 'exe':
@@ -18,4 +16,17 @@ if mode == 'exe':
   elif ext == 'js':
     os.system(f'node {path}')
 
-if mode == 'test': pass
\ No newline at end of file
+if mode == 'test': pass
+
+
+
+'''
+~/.config/Code/User/keybindings.json
+{
+  "key": "ctrl+shift+1",
+  "command": "workbench.action.terminal.sendSequence",
+  "args": {
+    "text": "python3 /home/quang/.local/lib/python3.10/site-packages/tayto/execute.py ${file} exe\u000D"
+  }
+},
+'''
\ No newline at end of file
